@@ -1,6 +1,8 @@
 import os
+# import wget
 
 from cloudmesh.burn.image import Image
+from cloudmesh.common.Shell import Shell
 
 
 class Iso:
@@ -13,4 +15,6 @@ class Iso:
         url = Iso.distribution[tag]
         destination = Image().directory + os.path.basename(url)
 
-        os.system(f'wget -O {destination} {url}')
+        Shell.download(url, destination, provider='system')
+        # wget.download(url, out=destination)
+        # os.system(f'wget -O {destination} {url}')
