@@ -1,4 +1,5 @@
 import os
+# import wget
 
 from cloudmesh.burn.burner.raspberryos import Burner as RaspberryOsBurner
 from cloudmesh.burn.usb import USB
@@ -53,11 +54,12 @@ class Burner:
             return ""
         else:
             banner("Installing pishrink.sh into /usr/local/bin")
+            script_name = Shell.download(
+                'https://raw.githubusercontent.com/Drewsif/PiShrink/master/pishrink.sh', 'pishrink.sh', provider='system')
             script = \
-                """
-                wget https://raw.githubusercontent.com/Drewsif/PiShrink/master/pishrink.sh
-                chmod +x pishrink.sh
-                sudo mv pishrink.sh /usr/local/bin
+                f"""
+                chmod +x {script_name}
+                sudo mv {script_name} /usr/local/bin
                 """
 
             result = JobScript.execute(script)
